@@ -5,7 +5,9 @@
 # March 2016
 
 elevation_3s <- function(lon, lat, path, ...) {
-	stopifnot(file.exists(path))
+
+	.check_path(path)
+	
 	stopifnot(lon >= -180 & lon <= 180)
 	stopifnot(lat >= -60 & lat <= 60)
 
@@ -31,7 +33,7 @@ elevation_3s <- function(lon, lat, path, ...) {
 }
 
 elevation_30s <- function(country, path, mask=TRUE, subs="", ...) {
-	stopifnot(dir.exists(path))
+	.check_path(path)
 	iso3 <- .getCountryISO(country)
 	if (mask) {
 		mskname <- "_msk"
@@ -42,7 +44,7 @@ elevation_30s <- function(country, path, mask=TRUE, subs="", ...) {
 	filename <- file.path(path, paste0(f, ".tif"))
 	if (!file.exists(filename)) {
 		pzip <- gsub("\\.tif$", ".zip", filename)
-		theurl <- paste0("http://biogeo.ucdavis.edu/data/geodata/elv/", f, ".zip")
+		theurl <- paste0(.data_url(), "elv/", f, ".zip")
 		.downloadDirect(theurl, pzip, unzip=TRUE, ...)
 	}
 	rast(filename)
@@ -52,7 +54,7 @@ elevation_30s <- function(country, path, mask=TRUE, subs="", ...) {
 
 elevation_global <- function(res, path, ...) {
 
-	stopifnot(dir.exists(path))
+	.check_path(path)
 	res <- as.character(res)
 	stopifnot(res %in% c("2.5", "5", "10", "0.5"))
 	fres <- ifelse(res=="0.5", "30s", paste0(res, "m"))
