@@ -1,5 +1,5 @@
 
-.wcurl <- "https://biogeo.ucdavis.edu/data/worldclim/v2.1/"
+.wcurl <- "https://geodata.ucdavis.edu/climate/worldclim/2_1/"
 
 .wccruts <- function(lon, lat, path, ...) {
 
@@ -7,7 +7,7 @@
 
 
 .wcerad <- function(lon, lat, path, ...) {
-	stopifnot(dir.exists(path))
+	.check_path(path)
 	r <- rast(res=5)
 	id <- cellFromXY(r, cbind(lon,lat))
 	if (is.na(id)) stop("invalid coordinates (lon/lat reversed?)")
@@ -29,7 +29,7 @@
 worldclim_tile <- function(var, lon, lat, path, ...) {
 	stopifnot(var %in% c("tavg", "tmin", "tmax", "prec", "bio", "bioc", "elev"))
 	if (var == "bioc") var <- "bio"
-	stopifnot(dir.exists(path))
+	.check_path(path)
 
 	r <- rast(res=30)
 	id <- cellFromXY(r, cbind(lon,lat))
@@ -55,7 +55,7 @@ worldclim_country <- function(country, var, path, ...) {
 	if (var == "bioc") var <- "bio"
 	iso <- .getCountryISO(country)
 	
-	stopifnot(dir.exists(path))
+	.check_path(path)
 	pth <- file.path(path, "wc2.1_country")
 	dir.create(pth, showWarnings=FALSE)
 
@@ -76,7 +76,7 @@ worldclim_global <- function(var, res, path, ...) {
 	stopifnot(res %in% c("2.5", "5", "10", "0.5"))
 	stopifnot(var %in% c("tavg", "tmin", "tmax", "prec", "bio", "bioc", "elev"))
 	if (var == "bioc") var <- "bio"
-	stopifnot(dir.exists(path))
+	.check_path(path)
 
 	fres <- ifelse(res=="0.5", "30s", paste0(res, "m"))
 	path <- file.path(path, paste0("wc2.1_", fres, "/"))
@@ -93,14 +93,15 @@ worldclim_global <- function(var, res, path, ...) {
 	ff <- file.path(path, ff)
 	if (!all(file.exists(ff))) {
 		.downloadDirect(paste0(.wcurl, "base/", zip), pzip, ...)
-		fz <- try(utils::unzip(pzip, exdir=path))
+		fz <- try(utils::unzip(pzip, exdir=path), silent=TRUE)
+		try(file.remove(pzip), silent=TRUE)
 		if (inherits(fz, "try-error")) {stop("download failed")}
 	}
 	rast(ff)
 }
 
 
-cmip6_world <- function(model, ssp, time, var, res, path, ...) {
+.cmip6_world_old <- function(model, ssp, time, var, res, path, ...) {
 
 	res <- as.character(res)
 	stopifnot(res %in% c("2.5", "5", "10"))
@@ -113,25 +114,94 @@ cmip6_world <- function(model, ssp, time, var, res, path, ...) {
 	# some combinations do not exist. Catch these here.
 	
 	if (var == "bio") var <- "bioc"
-	stopifnot(dir.exists(path))
+	.check_path(path)
 
 	fres <- ifelse(res==0.5, "30s", paste0(res, "m"))
 	path <- file.path(path, paste0("wc2.1_", fres, "/"))
 	dir.create(path, showWarnings=FALSE)
 	
-	zip <- paste0("wc2.1_", fres, "_", var, "_", model, "_ssp", ssp, "_", time, ".zip")
-	pzip <- file.path(path, zip)
-	outf <- gsub("\\.zip$", ".tif", zip)
+	outf <- paste0("wc2.1_", fres, "_", var, "_", model, "_ssp", ssp, "_", time, ".tif")
 	poutf <- file.path(path, outf)
-	if (!file.exists(pzip)) {
-		url <- paste0(.wcurl, "fut/", fres, "/", zip)
-		.downloadDirect(url, pzip, ...)
-	}
 	if (!file.exists(poutf)) {
-		fz <- try(utils::unzip(pzip, exdir=path, junkpaths=TRUE), silent=TRUE)
-		if (inherits(fz, "try-error")) { stop("unzip failed") }
+		if (!file.exists(outf)) {
+			url <- paste0(.wcurl, "cmip6/", fres, "/", model, "/ssp", ssp, "/", outf)
+			.downloadDirect(url, poutf, ...)
+		}
+		#fz <- try(utils::unzip(pzip, exdir=path, junkpaths=TRUE), silent=TRUE)
+		#try(file.remove(pzip), silent=TRUE)
+		#if (inherits(fz, "try-error")) { stop("unzip failed") }
 	}
 	rast(poutf)
 }
 
 
+
+.cmods <- c('ACCESS-CM2', 'ACCESS-ESM1-5', 'AWI-CM-1-1-MR', 'BCC-CSM2-MR', 'CanESM5', 'CanESM5-CanOE', 'CMCC-ESM2', 'CNRM-CM6-1', 'CNRM-CM6-1-HR', 'CNRM-ESM2-1', 'EC-Earth3-Veg', 'EC-Earth3-Veg-LR', 'FIO-ESM-2-0', 'GFDL-ESM4', 'GISS-E2-1-G', 'GISS-E2-1-H', 'HadGEM3-GC31-LL', 'INM-CM4-8', 'INM-CM5-0', 'IPSL-CM6A-LR', 'MIROC-ES2L', 'MIROC6', 'MPI-ESM1-2-HR', 'MPI-ESM1-2-LR', 'MRI-ESM2-0', 'UKESM1-0-LL')
+
+.c6url <- "https://geodata.ucdavis.edu/cmip6/"
+
+
+.check_cmip6 <- function(res, var, ssp, model, time) {
+	stopifnot(ssp %in% c("126", "245", "370", "585"))
+	stopifnot(res %in% c("0.5", "2.5", "5", "10"))
+	stopifnot(var %in% c("tmin", "tmax", "prec", "bio", "bioc"))
+	if (!(model %in% .cmods)) {
+		stop(paste("not a valid model, use of of:\n", paste(.cmods, collapse=", ")))
+	}
+	stopifnot(time %in% c("2021-2040", "2041-2060", "2061-2080"))
+
+	# some combinations do not exist. Catch these here.
+
+}
+
+cmip6_world <- function(model, ssp, time, var, res, path, ...) {
+
+	res <- as.character(res)
+	fres <- ifelse(res==0.5, "30s", paste0(res, "m"))
+	ssp <- as.character(ssp)
+	if (var == "bio") var <- "bioc"
+	.check_cmip6(res, var, ssp, model, time)
+	.check_path(path)
+	path <- file.path(path, paste0("wc2.1_", fres, "/"))
+	dir.create(path, showWarnings=FALSE)
+	
+	outf <- paste0("wc2.1_", fres, "_", var, "_", model, "_ssp", ssp, "_", time, ".tif")
+	poutf <- file.path(path, outf)
+	if (!file.exists(poutf)) {
+		if (!file.exists(outf)) {
+			url <- paste0(.c6url, fres, "/", model, "/ssp", ssp, "/", outf)
+			.downloadDirect(url, poutf, ...)
+		}
+		#fz <- try(utils::unzip(pzip, exdir=path, junkpaths=TRUE), silent=TRUE)
+		#try(file.remove(pzip), silent=TRUE)
+		#if (inherits(fz, "try-error")) { stop("unzip failed") }
+	}
+	rast(poutf)
+}
+
+
+cmip6_tile <- function(lon, lat, model, ssp, time, var, path, ...) {
+	ssp <- as.character(ssp)
+	if (var == "bio") var <- "bioc"
+	.check_cmip6(0.5, var, ssp, model, time)
+	.check_path(path)
+	path <- file.path(path, paste0("wc2.1_30s/"))
+	dir.create(path, showWarnings=FALSE)
+
+	r <- rast(res=30)
+	id <- cellFromXY(r, cbind(lon,lat))
+	if (is.na(id)) stop("invalid coordinates (lon/lat reversed?)")
+
+	pth <- file.path(path, "wc2.1_tiles")
+	dir.create(pth, showWarnings=FALSE)
+
+	fname <- paste0("wc2.1_30s_", var, "_", model, "_ssp", ssp, "_", time, "_tile-", id, ".tif")
+	outfname <- file.path(path, fname)
+
+	if (!file.exists(outfname)) {
+		turl <- paste0(.c6url, "tiles/", model, "/ssp", ssp, "/", fname)
+		.downloadDirect(turl, outfname, ...)
+	}
+	rast(outfname)
+}
+
